# OpenTTY 1.2.1 "The Netman Upgrade"

> In this upgrade Mr. Lima finish 
> NETMAN project and it charge the OpenTTY
> version family, IT'S OpenTTY 95!

## Release Notes

1. Added Experimental Features

Experimental Features is a control for beta assets  
installation and plugins, it charges user experience of profile  
with non-official resources.  

List of Experimental Features:
```
{
	"Are-ROOT": False, # Beahivor as computer admin
	"ENABLE": False, # Add command enable and disable to control acessible commands
	"Desktop": False, # Add support for Virtual Desktop emulation
	"QT-SDK": False, # Add asset QT-SDK into mirrors
	"Trust-Mirror": False, # Add ability to import mirrors from json files
	"RRAW-IS-CURL": False, # If TRUE command rraw will call CURL
	"Dumpsys": False, # Enable dumpsys
	"GAMERULES": False, # Enable gamerules and gamemode charge
},
```

2. Added command 'PULL' to save 'library' status for a file
3. Removed Command Line splitting

Contribuitors: Mr. Lima
Github Repository: https://github.com/fetuber4095/OpenTTY